@@ -29,7 +29,8 @@ class ApiTests extends ApiTestFixtureBase {
   }
 
   async testRequestHeader() {
-    await fetch('/fake-rpc');
+    const rpcUrls: string[] = this.testParams.rpcUrls;
+    await Promise.all(rpcUrls.map(url => fetch(url)));
   }
 
   async testCreateTab() {
@@ -104,6 +105,8 @@ class ApiTests extends ApiTestFixtureBase {
     await waitFor(closedPromise.promise);
   }
 
+  async testErrorShownOnMojoPipeError() {}
+
   async testShowProfilePicker() {
     assertDefined(this.host.showProfilePicker);
     this.host.showProfilePicker();
@@ -575,15 +578,11 @@ class ApiTests extends ApiTestFixtureBase {
 
   async testGetDefaultTabContextPermissionState() {
     assertDefined(this.host.getDefaultTabContextPermissionState);
-
     const defaultTabContextState =
         observeSequence(this.host.getDefaultTabContextPermissionState());
-
-    assertFalse(await defaultTabContextState.next());
-
+    assertTrue(await defaultTabContextState.next() as boolean);
     await this.advanceToNextStep();
-
-    assertTrue(await defaultTabContextState.next());
+    assertFalse(await defaultTabContextState.next() as boolean);
   }
 
   async testGetOsHotkeyState() {
@@ -705,12 +704,16 @@ class ApiTests extends ApiTestFixtureBase {
     assertDefined(metrics.onResponseRated);
     assertDefined(metrics.onUserInputSubmitted);
     assertDefined(metrics.onReaction);
+    assertDefined(metrics.onContextUploadStarted);
+    assertDefined(metrics.onContextUploadCompleted);
     assertDefined(metrics.onResponseStarted);
     assertDefined(metrics.onResponseStopped);
     assertDefined(metrics.onSessionTerminated);
     assertDefined(metrics.onClosedCaptionsShown);
     metrics.onResponseRated(true);
     metrics.onUserInputSubmitted(WebClientMode.TEXT);
+    metrics.onContextUploadStarted();
+    metrics.onContextUploadCompleted();
     metrics.onReaction(MetricUserInputReactionType.MODEL);
     metrics.onResponseStarted();
     metrics.onResponseStopped({cause: ResponseStopCause.USER});
@@ -904,6 +907,15 @@ class ApiTests extends ApiTestFixtureBase {
     assertEquals(url.pathname, '/glic/browser_tests/test.html');
   }
 
+  async testNavigateToAboutBlank() {
+    // Navigation to about:blank will destroy this test client, so the code
+    // below will first allow this test function to return, and then navigate.
+    (async () => {
+      await sleep(100);
+      location.href = 'about:blank';
+    })();
+  }
+
   async testCallingApiWhileHiddenRecordsMetrics() {
     assertDefined(this.host.createTab);
     await this.advanceToNextStep();
@@ -1716,6 +1728,56 @@ class ApiTests extends ApiTestFixtureBase {
     assertEquals('Ruth', authorTag.content);
   }
 
+  async testAdditionalContext() {
+    const additionalContextPromise = new Promise<void>(resolve => {
+      this.host.getAdditionalContext!().subscribe(async context => {
+        assertEquals(context.name, 'part with everything');
+        assertDefined(context.tabId);
+        assertTrue(context.tabId!.length > 0);
+        assertDefined(context.frameUrl);
+        assertTrue(context.frameUrl!.length > 0);
+        assertEquals(context.parts.length, 5);
+
+        const part1 = context.parts[0]!;
+        assertDefined(part1.data);
+        assertEquals(part1.data!.type, 'text/plain');
+        const data1 = new Uint8Array(await part1.data!.arrayBuffer());
+        assertEquals(data1.length, 4);
+        assertEquals(data1[0], 't'.charCodeAt(0));
+
+        const part2 = context.parts[1]!;
+        assertUndefined(part2.data);
+        assertDefined(part2.screenshot);
+        assertEquals(part2.screenshot!.widthPixels, 10);
+        assertEquals(part2.screenshot!.heightPixels, 20);
+        assertEquals(part2.screenshot!.mimeType, 'image/png');
+        const data2 = new Uint8Array(part2.screenshot!.data);
+        assertEquals(data2.length, 4);
+        assertEquals(data2[0], 1);
+
+        const part3 = context.parts[2]!;
+        assertDefined(part3.webPageData);
+        assertEquals(
+            part3.webPageData!.mainDocument.innerText, 'some inner text');
+
+        const part4 = context.parts[3]!;
+        assertDefined(part4.annotatedPageData);
+
+        const part5 = context.parts[4]!;
+        assertDefined(part5.pdf);
+        assertDefined(part5.pdf!.pdfData);
+        const pdfText = await new Response(part5.pdf!.pdfData!).text();
+        assertEquals(pdfText, 'pdf');
+
+
+        resolve();
+      });
+    });
+
+    await this.advanceToNextStep();
+    await additionalContextPromise;
+  }
+
   private async closePanelAndWaitUntilInactive() {
     assertDefined(this.host.closePanel);
     await this.host.closePanel();
@@ -1734,6 +1796,8 @@ class ApiTests extends ApiTestFixtureBase {
         return 'RESET_SIZE_AND_LOCATION_ON_OPEN';
       case HostCapability.GET_MODEL_QUALITY_CLIENT_ID:
         return 'GET_MODEL_QUALITY_CLIENT_ID';
+      case HostCapability.MULTI_INSTANCE:
+        return 'MULTI_INSTANCE';
       default:
         return 'NEW_ENUM_NOT_IMPLEMENTED';
     }
