@@ -37,8 +37,8 @@ class LensOverlayWebUIBrowserTest : public WebUIMochaBrowserTest {
     set_test_loader_host(chrome::kChromeUILensOverlayHost);
     scoped_feature_list_.InitWithFeatures(
         /*enabled_features=*/{lens::features::kLensOverlay},
-        /*disabled_features=*/{
-            lens::features::kLensOverlayContextualSearchbox});
+        /*disabled_features=*/{lens::features::kLensOverlayContextualSearchbox,
+                               lens::features::kLensSearchZeroStateCsb});
   }
 
   void SetUp() override {
