@@ -85,6 +85,12 @@ IN_PROC_BROWSER_TEST_F(PasswordManagerUITest, PasswordsSection) {
   RunTest("password_manager/passwords_section_test.js", "mocha.run()");
 }
 
+IN_PROC_BROWSER_TEST_F(PasswordManagerUITest,
+                       RemoveActorLoginPermissionDialog) {
+  RunTest("password_manager/remove_actor_login_permission_dialog_test.js",
+          "mocha.run()");
+}
+
 IN_PROC_BROWSER_TEST_F(PasswordManagerUITest, Routing) {
   RunTest("password_manager/password_manager_routing_test.js", "mocha.run()");
 }
